@@ -1,11 +1,10 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Gentoo::MetaEbuild::Spec::Base;
 
-our $VERSION = '1.000001';
+our $VERSION = '1.000002';
 
 # ABSTRACT: A Base Class for Gentoo MetaEbuild Specifications.
 
@@ -79,6 +78,9 @@ class_has '_schema_creator' => (
   handles => { _make_schema => 'execute', },
 );
 
+__PACKAGE__->meta->make_immutable;
+no Moose;
+
 sub _build__schema_creator {
   require Data::Rx;
   my $rx = Data::Rx->new();
@@ -135,9 +137,6 @@ sub check {
   return $self->_schema($opts)->check($json_data);
 }
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
-
 1;
 
 __END__
@@ -152,7 +151,7 @@ Gentoo::MetaEbuild::Spec::Base - A Base Class for Gentoo MetaEbuild Specificatio
 
 =head1 VERSION
 
-version 1.000001
+version 1.000002
 
 =head1 SYNOPSIS
 
@@ -209,7 +208,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2017 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
